@@ -1,6 +1,9 @@
 # Import the whole augmentation tree
 
 from . import nodes
+from . import groups
 from . import links
+from . import devices
+from . import plugin
 from . import topology
 from . import main
